==> qt3d-everywhere-src-5.15.0.zip: qt3d-everywhere-src-5.15.0/src/render/surfaces/vulkaninstance.cpp <==
/****************************************************************************
**
** Copyright (C) 2020 Klaralvdalens Datakonsult AB (KDAB).
** Contact: https://www.qt.io/licensing/
**
** This file is part of the QtGui module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#include "vulkaninstance_p.h"
#include <QVulkanInstance>

QT_BEGIN_NAMESPACE

namespace Qt3DRender {

QVulkanInstance &staticVulkanInstance() noexcept
{
    static QVulkanInstance* vkInstance = []
    {
        QVulkanInstance* v = new QVulkanInstance;
#ifndef Q_OS_ANDROID
        v->setLayers({ "VK_LAYER_LUNARG_standard_validation" });
#else
        v->setLayers(QByteArrayList()
                               << "VK_LAYER_GOOGLE_threading"
                               << "VK_LAYER_LUNARG_parameter_validation"
                               << "VK_LAYER_LUNARG_object_tracker"
                               << "VK_LAYER_LUNARG_core_validation"
                               << "VK_LAYER_LUNARG_image"
                               << "VK_LAYER_LUNARG_swapchain"
                               << "VK_LAYER_GOOGLE_unique_objects");
#endif

        if (!v->create()) {
            qWarning("Failed to create Vulkan instance");
        }
        return v;
    }();
    return *vkInstance;
}

} // Qt3DRender

QT_END_NAMESPACE

==> qt3d-everywhere-src-6.0.1.zip: qt3d-everywhere-src-6.0.1/src/render/surfaces/vulkaninstance.cpp <==
/****************************************************************************
**
** Copyright (C) 2020 Klaralvdalens Datakonsult AB (KDAB).
** Contact: https://www.qt.io/licensing/
**
** This file is part of the QtGui module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#include "vulkaninstance_p.h"

#if QT_CONFIG(vulkan)

#include <QVulkanInstance>

QT_BEGIN_NAMESPACE

namespace Qt3DRender {

QVulkanInstance &staticVulkanInstance() noexcept
{
    static QVulkanInstance* vkInstance = []
    {
        QVulkanInstance* v = new QVulkanInstance;
#if defined(NDEBUG)
        constexpr bool debug_mode = false;
#else
        constexpr bool debug_mode = true;
#endif
        if (debug_mode || qgetenv("QT3D_VULKAN_VALIDATION").toInt())
            v->setLayers({ "VK_LAYER_KHRONOS_validation" });

        if (!v->create())
            qWarning("Failed to create Vulkan instance");

        return v;
    }();
    return *vkInstance;
}

} // Qt3DRender

QT_END_NAMESPACE

#endif
